@@ -9,7 +9,7 @@ DBD::XMLSimple - Access XML data via the DBI interface
 
 =head1 VERSION
 
-Version 0.01
+Version 0.02
 
 =cut
 
@@ -17,11 +17,7 @@ Version 0.01
 
 Reads XML and makes it available via DBI.
 
-GPL2.  Don't use this yet, it's a WIP
-Change x_import to xmls_import once it's been registered
-Re-uses code from existing DBD Drivers, especially DBD::AnyData
-Nigel Horne: njh@bandsman.co.uk
-
+    use FindBin qw($Bin);
     use DBI;
 
     my $dbh = DBI->connect('dbi:XMLSimple(RaiseError => 1):');
@@ -58,7 +54,7 @@ use base qw(DBI::DBD::SqlEngine);
 
 use vars qw($VERSION $drh $methods_already_installed);
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 our $drh = undef;
 
 sub driver
@@ -277,9 +273,11 @@ Fields must be in the same order so this does not work (yet):
 		<col1>d</col1>
 	<row>
 
+Change x_import to xmls_import once it's been registered
+
 =head1 SEE ALSO
 
-L<DBD::AnyData>
+L<DBD::AnyData>, which was also used as a template for this module.
 
 =head1 SUPPORT
 
